// Create a new FTPClient object
var ftp = new FTPClient();

// Grab references to all the form elements
var serverText = document.getElementById("Server");
var userNameText = document.getElementById("UserName");
var passwordText = document.getElementById("Password");
var commandText = document.getElementById("Command");
var resultText = document.getElementById("Result");

// This function is called when the 'Get Directory' button is pressed.
function executeCommand()
{
    // Validate the text-boxes.
    if (serverText.value==="" || userNameText.value==="" 
        || passwordText.value==="" || commandText.value==="")
    {
        alert("Please enter all fields.");
        return;
    }

    // Set up event-handlers.  
    // These are called when FTPClient completes particular operations.
    ftp.onInitialize = onInitialize;             // called when initialization is complete
    ftp.onConnect = onConnect;                   // called when a connection has been made (or failed)
    ftp.onDisconnect = onDisconnect;             // called when a connection has been closed
    ftp.onExecuteCommand = onExecuteCommand;     // called when a command has been executed
    ftp.onError = onError;                       // called when an error occurs

    // Set connection parameters.    
    ftp.remoteHost = serverText.value;
    ftp.userName = userNameText.value;
    ftp.password = passwordText.value;
    
    // if we haven't yet initialized then do so, otherwise connect.
    setStatus("Initializing");
    if (!ftp.isInitialized())
    {
        ftp.initialize("IntegralFTP.jar", true, "DEBUG", false);
        // the function, onInitialize, will called when initialization is complete
    }
    else
    {
        ftp.connect();
        // the function, onConnect, will called when the connection attempt is complete
    }
}

// Called when initialization is complete
function onInitialize(status)
{
    setStatus("Connecting");
    ftp.connect();
    // onInitialize will called when a connection has been made (or failed)
}

// Called when a connection has been made (or failed)
function onConnect(status)
{
    if (status.success)
    {
        setStatus("Executing command");
        ftp.executeCommand(commandText.value);
        // onExecuteCommand will be called when the command has been executed
    }
    else
    {
        setStatus("Could not connect.");
    }
}

// Called when a command has been executed
function onExecuteCommand(status, command, result)
{
    if (status.success)
    {
        setStatus("Command executed");
		resultText.value = result;
    }
    else
    {
        setStatus("Could not execute command.");
    }
    
    // onDisconnect will be called when a connection has been closed
    ftp.disconnect();
}

// Called when a connection has been closed
function onDisconnect(status)
{
    setStatus("Disconnected");
}

// Called when an error occurs
function onError(status)
{
    alert("Error: " + status.errorMessage);
}

// Updates the text in the status text-box
function setStatus(text)
{
    var statusText = document.getElementById("Status");
    statusText.value = text;
}
